@@ -16,7 +16,6 @@
 # Lint as: python3
 """The French Language Understanding Evaluation (FLUE) benchmark."""
 
-from __future__ import absolute_import, division, print_function
 
 import csv
 import os
@@ -25,7 +24,6 @@ import textwrap
 import unicodedata
 from shutil import copyfile
 
-import six
 from lxml import etree
 
 import datasets
@@ -203,15 +201,13 @@ class Flue(datasets.GeneratorBasedBuilder):
 
     def _info(self):
         if self.config.name == "CLS" or self.config.name == "XNLI":
-            features = {
-                text_feature: datasets.Value("string") for text_feature in six.iterkeys(self.config.text_features)
-            }
+            features = {text_feature: datasets.Value("string") for text_feature in self.config.text_features.keys()}
             features[self.config.label_column] = datasets.features.ClassLabel(names=self.config.label_classes)
             features["idx"] = datasets.Value("int32")
         elif self.config.name == "WSD-V":
             features = {
                 text_feature: datasets.Sequence(datasets.Value("string"))
-                for text_feature in six.iterkeys(self.config.text_features)
+                for text_feature in self.config.text_features.keys()
             }
             features["fine_pos_tags"] = datasets.Sequence(
                 datasets.features.ClassLabel(
@@ -275,9 +271,7 @@ class Flue(datasets.GeneratorBasedBuilder):
             features["disambiguate_labels"] = datasets.Sequence(datasets.Value("string"))
             features["idx"] = datasets.Value("string")
         else:
-            features = {
-                text_feature: datasets.Value("string") for text_feature in six.iterkeys(self.config.text_features)
-            }
+            features = {text_feature: datasets.Value("string") for text_feature in self.config.text_features.keys()}
             features[self.config.label_column] = datasets.Value("int32")
             features["idx"] = datasets.Value("int32")
         return datasets.DatasetInfo(
@@ -467,16 +461,16 @@ class Flue(datasets.GeneratorBasedBuilder):
         Converts `text` to Unicode (if it's not already), assuming UTF-8 input.
         from: https://github.com/getalp/Flaubert/blob/master/tools/clean_text.py
         """
-        # six_ensure_text is copied from https://github.com/benjaminp/six
-        def six_ensure_text(s, encoding="utf-8", errors="strict"):
-            if isinstance(s, six.binary_type):
+
+        def ensure_text(s, encoding="utf-8", errors="strict"):
+            if isinstance(s, bytes):
                 return s.decode(encoding, errors)
-            elif isinstance(s, six.text_type):
+            elif isinstance(s, str):
                 return s
             else:
                 raise TypeError("not expecting type '%s'" % type(s))
 
-        return six_ensure_text(text, encoding="utf-8", errors="ignore")
+        return ensure_text(text, encoding="utf-8", errors="ignore")
 
     def _cleaner(self, text):
         """
@@ -502,7 +496,7 @@ class Flue(datasets.GeneratorBasedBuilder):
         return text
 
     def _wsdv_prepare_data(self, dirpath):
-        """ Get data paths from FSE dir"""
+        """Get data paths from FSE dir"""
         paths = {}
 
         for f in os.listdir(dirpath):
@@ -526,10 +520,10 @@ class Flue(datasets.GeneratorBasedBuilder):
 
 # The WSDDatasetReader classes come from https://github.com/getalp/Flaubert/blob/master/flue/wsd/verbs/modules/dataset.py
 class WSDDatasetReader:
-    """ Class to read a WSD data directory. The directory should contain .data.xml and .gold.key.txt files"""
+    """Class to read a WSD data directory. The directory should contain .data.xml and .gold.key.txt files"""
 
     def get_data_paths(self, indir):
-        """ Get file paths from WSD dir """
+        """Get file paths from WSD dir"""
         xml_fpath, gold_fpath = None, None
 
         for f in os.listdir(indir):
@@ -552,7 +546,7 @@ class WSDDatasetReader:
         }
 
     def read_from_data_dirs(self, data_dirs):
-        """ Read WSD data and return as WSDDataset """
+        """Read WSD data and return as WSDDataset"""
         for d in data_dirs:
             xml_fpath, gold_fpath = self.get_data_paths(d)
 
@@ -620,13 +614,13 @@ class WSDDatasetReader:
                     )
 
     def read_sentences(self, data_dir, keep_mwe=True):
-        """ Read sentences from WSD data"""
+        """Read sentences from WSD data"""
 
         xml_fpath, _ = self.get_data_paths(data_dir)
         return self.read_sentences_from_xml(xml_fpath, keep_mwe=keep_mwe)
 
     def read_sentences_from_xml(self, infile, keep_mwe=False):
-        """ Read sentences from xml file """
+        """Read sentences from xml file"""
 
         # Parse xml
         tree = etree.parse(infile)
@@ -641,5 +635,5 @@ class WSDDatasetReader:
                 yield sent
 
     def read_target_keys(self, infile):
-        """ Read target keys """
+        """Read target keys"""
         return [x.rstrip("\n") for x in open(infile, encoding="utf-8").readlines()]
