@@ -1,6 +1,5 @@
 """TODO(lince): Add a description here."""
 
-from __future__ import absolute_import, division, print_function
 
 import csv
 import os
@@ -8,8 +7,6 @@ import re
 import textwrap
 from itertools import groupby
 
-import six
-
 import datasets
 
 
@@ -506,7 +503,7 @@ class Lince(datasets.GeneratorBasedBuilder):
                     "filepath": os.path.join(data_dir, "test.conll"),
                     "colnames": {
                         key: self.config.colnames[key]
-                        for key in six.iterkeys(self.config.colnames)
+                        for key in self.config.colnames.keys()
                         if key != self.config.label_column
                     },
                 },
