@@ -14,7 +14,6 @@
 # limitations under the License.
 """TODO: Add a description here."""
 
-from __future__ import absolute_import, division, print_function
 
 import glob
 import os
@@ -50,7 +49,7 @@ _URL = "https://github.com/boschresearch/sofc-exp_textmining_resources/archive/m
 
 
 class SOFCMaterialsArticles(datasets.GeneratorBasedBuilder):
-    """"""
+    """ """
 
     VERSION = datasets.Version("1.1.0")
 
@@ -281,7 +280,7 @@ class SOFCMaterialsArticles(datasets.GeneratorBasedBuilder):
         ]
 
     def _generate_examples(self, names, data_dir, split):
-        """ Yields examples. """
+        """Yields examples."""
         # The dataset consists of the original article text as well as annotations
         textfile_base_path = os.path.join(data_dir, "texts")
         annotations_base_path = os.path.join(data_dir, "annotations")
@@ -417,8 +416,8 @@ class SOFCMaterialsArticles(datasets.GeneratorBasedBuilder):
 
             # Iterate through the links data, which is in a simple tab-delimited format
             links = []
-            for l in links_raw:
-                _, relation_label, start_span_id, end_span_id = l.split("\t")
+            for link in links_raw:
+                _, relation_label, start_span_id, end_span_id = link.split("\t")
 
                 link_out = {
                     "relation_label": relation_label,
