@@ -1,6 +1,5 @@
 """TODO(xtreme): Add a description here."""
 
-from __future__ import absolute_import, division, print_function
 
 import csv
 import glob
@@ -8,8 +7,6 @@ import json
 import os
 import textwrap
 
-import six
-
 import datasets
 
 
@@ -71,6 +68,7 @@ _TATOEBA_LANG = [
     "spa",
     "swh",
     "tam",
+    "tel",
     "tgl",
     "tha",
     "tur",
@@ -441,7 +439,7 @@ class Xtreme(datasets.GeneratorBasedBuilder):
 
     def _info(self):
         # TODO(xtreme): Specifies the datasets.DatasetInfo object
-        features = {text_feature: datasets.Value("string") for text_feature in six.iterkeys(self.config.text_features)}
+        features = {text_feature: datasets.Value("string") for text_feature in self.config.text_features.keys()}
         if "answers" in features.keys():
             features["answers"] = datasets.features.Sequence(
                 {"answer_start": datasets.Value("int32"), "text": datasets.Value("string")}
@@ -933,7 +931,7 @@ class Xtreme(datasets.GeneratorBasedBuilder):
                 ner_tags = []
                 langs = []
                 for line in f:
-                    if line.startswith("-DOCSTART-") or line == "" or line == "\n":
+                    if line == "" or line == "\n":
                         if tokens:
                             yield guid_index, {"tokens": tokens, "ner_tags": ner_tags, "langs": langs}
                             guid_index += 1
