@@ -22,19 +22,21 @@ import os
 import re
 import shutil
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, List, Optional
+from typing import TYPE_CHECKING, List, Optional, Union
 
 import pyarrow as pa
-import pyarrow.parquet
+import pyarrow.parquet as pq
 
 from datasets.utils.file_utils import DownloadConfig
 
 from .naming import _split_re, filename_for_dataset_split
+from .table import InMemoryTable, MemoryMappedTable, Table, concat_tables
 from .utils import cached_path, logging
 
 
 if TYPE_CHECKING:
     from .info import DatasetInfo  # noqa: F401
+    from .splits import Split  # noqa: F401
 
 
 logger = logging.get_logger(__name__)
@@ -51,7 +53,7 @@ _SUB_SPEC_RE = re.compile(
     :
     ((?P<to>-?\d+)
      (?P<to_pct>%)?)?
- \])?
+ \])?(\((?P<rounding>[^\)]*)\))?
 $
 """.format(
         split_re=_split_re[1:-1]
@@ -149,11 +151,11 @@ class BaseReader:
         self._info: Optional["DatasetInfo"] = info
         self._filetype_suffix: Optional[str] = None
 
-    def _get_dataset_from_filename(self, filename_skip_take, in_memory=False):
+    def _get_table_from_filename(self, filename_skip_take, in_memory=False) -> Table:
         """Returns a Dataset instance from given (filename, skip, take)."""
         raise NotImplementedError
 
-    def _read_files(self, files, in_memory=False) -> pa.Table:
+    def _read_files(self, files, in_memory=False) -> Table:
         """Returns Dataset for given file instructions.
 
         Args:
@@ -168,15 +170,15 @@ class BaseReader:
         for f in files:
             f.update(filename=os.path.join(self._path, f["filename"]))
         for f_dict in files:
-            pa_table: pa.Table = self._get_dataset_from_filename(f_dict, in_memory=in_memory)
+            pa_table: Table = self._get_table_from_filename(f_dict, in_memory=in_memory)
             pa_tables.append(pa_table)
         pa_tables = [t for t in pa_tables if len(t) > 0]
         if not pa_tables and (self._info is None or self._info.features is None):
             raise ValueError(
                 "Tried to read an empty table. Please specify at least info.features to create an empty table with the right type."
             )
-        pa_tables = pa_tables or [pa.Table.from_batches([], schema=pa.schema(self._info.features.type))]
-        pa_table = pa.concat_tables(pa_tables)
+        pa_tables = pa_tables or [InMemoryTable.from_batches([], schema=pa.schema(self._info.features.type))]
+        pa_table = concat_tables(pa_tables) if len(pa_tables) != 1 else pa_tables[0]
         return pa_table
 
     def get_file_instructions(self, name, instruction, split_infos):
@@ -216,8 +218,8 @@ class BaseReader:
 
     def read_files(
         self,
-        files,
-        original_instructions=None,
+        files: List[dict],
+        original_instructions: Union[None, "ReadInstruction", "Split"] = None,
         in_memory=False,
     ):
         """Returns single Dataset instance for the set of file instructions.
@@ -234,10 +236,14 @@ class BaseReader:
         """
         # Prepend path to filename
         pa_table = self._read_files(files, in_memory=in_memory)
-        files = copy.deepcopy(files)
-        for f in files:
-            f.update(filename=os.path.join(self._path, f["filename"]))
-        dataset_kwargs = dict(arrow_table=pa_table, data_files=files, info=self._info, split=original_instructions)
+        # If original_instructions is not None, convert it to a human-readable NamedSplit
+        if original_instructions is not None:
+            from .splits import Split  # noqa
+
+            split = Split(str(original_instructions))
+        else:
+            split = None
+        dataset_kwargs = dict(arrow_table=pa_table, info=self._info, split=split)
         return dataset_kwargs
 
     def download_from_hf_gcs(self, download_config: DownloadConfig, relative_data_dir):
@@ -292,21 +298,21 @@ class ArrowReader(BaseReader):
         super().__init__(path, info)
         self._filetype_suffix = "arrow"
 
-    def _get_dataset_from_filename(self, filename_skip_take, in_memory=False):
+    def _get_table_from_filename(self, filename_skip_take, in_memory=False) -> Table:
         """Returns a Dataset instance from given (filename, skip, take)."""
         filename, skip, take = (
             filename_skip_take["filename"],
             filename_skip_take["skip"] if "skip" in filename_skip_take else None,
             filename_skip_take["take"] if "take" in filename_skip_take else None,
         )
-        pa_table = ArrowReader.read_table(filename, in_memory=in_memory)
+        table = ArrowReader.read_table(filename, in_memory=in_memory)
         # here we don't want to slice an empty table, or it may segfault
-        if skip is not None and take is not None and not (skip == 0 and take == len(pa_table)):
-            pa_table = pa_table.slice(skip, take)
-        return pa_table
+        if skip is not None and take is not None and not (skip == 0 and take == len(table)):
+            table = table.slice(skip, take)
+        return table
 
     @staticmethod
-    def read_table(filename, in_memory=False):
+    def read_table(filename, in_memory=False) -> Table:
         """
         Read table from file.
 
@@ -317,12 +323,8 @@ class ArrowReader(BaseReader):
         Returns:
             pyarrow.Table
         """
-        # Stream backed by memory-mapped file / file descriptor
-        stream_from = pa.memory_map if not in_memory else pa.input_stream
-        stream = stream_from(filename)
-        f = pa.ipc.open_stream(stream)
-        pa_table = f.read_all()
-        return pa_table
+        table_cls = InMemoryTable if in_memory else MemoryMappedTable
+        return table_cls.from_file(filename)
 
 
 class ParquetReader(BaseReader):
@@ -341,7 +343,7 @@ class ParquetReader(BaseReader):
         super().__init__(path, info)
         self._filetype_suffix = "parquet"
 
-    def _get_dataset_from_filename(self, filename_skip_take, **kwargs):
+    def _get_table_from_filename(self, filename_skip_take, **kwargs):
         """Returns a Dataset instance from given (filename, skip, take)."""
         filename, skip, take = (
             filename_skip_take["filename"],
@@ -349,7 +351,7 @@ class ParquetReader(BaseReader):
             filename_skip_take["take"] if "take" in filename_skip_take else None,
         )
         # Parquet read_table always loads data in memory, independently of memory_map
-        pa_table = pa.parquet.read_table(filename, memory_map=True)
+        pa_table = pq.read_table(filename, memory_map=True)
         # here we don't want to slice an empty table, or it may segfault
         if skip is not None and take is not None and not (skip == 0 and take == len(pa_table)):
             pa_table = pa_table.slice(skip, take)
@@ -384,7 +386,7 @@ class _RelativeInstruction:
             raise AssertionError("Percent slice boundaries must be > -100 and < 100.")
 
 
-def _str_to_relative_instruction(spec):
+def _str_to_read_instruction(spec):
     """Returns ReadInstruction for given string."""
     res = _SUB_SPEC_RE.match(spec)
     if not res:
@@ -392,7 +394,7 @@ def _str_to_relative_instruction(spec):
     unit = "%" if res.group("from_pct") or res.group("to_pct") else "abs"
     return ReadInstruction(
         split_name=res.group("split"),
-        rounding="closest",
+        rounding=res.group("rounding") if res.group("rounding") else "closest",
         from_=int(res.group("from")) if res.group("from") else None,
         to=int(res.group("to")) if res.group("to") else None,
         unit=unit,
@@ -448,7 +450,7 @@ def _rel_to_abs_instr(rel_instr, name2len):
     return _AbsoluteInstruction(split, from_, to)
 
 
-class ReadInstruction(object):
+class ReadInstruction:
     """Reading instruction for a dataset.
 
     Examples of usage:
@@ -466,8 +468,8 @@ class ReadInstruction(object):
     ds = datasets.load_dataset('mnist', split=ReadInstruction.from_spec(
             'test[:33%]+train[1:-1]'))
     ds = datasets.load_dataset('mnist', split=(
-            ReadInstruction.('test', to=33, unit='%') +
-            ReadInstruction.('train', from_=1, to=-1, unit='abs')))
+            ReadInstruction('test', to=33, unit='%') +
+            ReadInstruction('train', from_=1, to=-1, unit='abs')))
 
     # 10-fold validation:
     tests = datasets.load_dataset(
@@ -476,7 +478,7 @@ class ReadInstruction(object):
              for k in range(0, 100, 10)])
     trains = datasets.load_dataset(
             'mnist',
-            [RI('train', to=k, unit='%') + RI('train', from_=k+10, unit='%')
+            [ReadInstruction('train', to=k, unit='%') + ReadInstruction('train', from_=k+10, unit='%')
              for k in range(0, 100, 10)])
     ```
 
@@ -544,8 +546,28 @@ class ReadInstruction(object):
         subs = _ADDITION_SEP_RE.split(spec)
         if not subs:
             raise AssertionError("No instructions could be built out of %s" % spec)
-        instruction = _str_to_relative_instruction(subs[0])
-        return sum([_str_to_relative_instruction(sub) for sub in subs[1:]], instruction)
+        instruction = _str_to_read_instruction(subs[0])
+        return sum([_str_to_read_instruction(sub) for sub in subs[1:]], instruction)
+
+    def to_spec(self):
+        rel_instr_specs = []
+        for rel_instr in self._relative_instructions:
+            rel_instr_spec = rel_instr.splitname
+            if rel_instr.from_ is not None or rel_instr.to is not None:
+                from_ = rel_instr.from_
+                to = rel_instr.to
+                unit = rel_instr.unit
+                rounding = rel_instr.rounding
+                unit = unit if unit == "%" else ""
+                from_ = str(from_) + unit if from_ is not None else ""
+                to = str(to) + unit if to is not None else ""
+                slice_str = f"[{from_}:{to}]"
+                rounding_str = (
+                    f"({rounding})" if unit == "%" and rounding is not None and rounding != "closest" else ""
+                )
+                rel_instr_spec += slice_str + rounding_str
+            rel_instr_specs.append(rel_instr_spec)
+        return "+".join(rel_instr_specs)
 
     def __add__(self, other):
         """Returns a new ReadInstruction obj, result of appending other to self."""
@@ -554,10 +576,13 @@ class ReadInstruction(object):
             raise AssertionError(msg)
         other_ris = other._relative_instructions  # pylint: disable=protected-access
         if self._relative_instructions[0].rounding != other_ris[0].rounding:
-            raise AssertionError("It is forbidden to sum ReadInstruction instances " "with different rounding values.")
+            raise AssertionError("It is forbidden to sum ReadInstruction instances with different rounding values.")
         return self._read_instruction_from_relative_instructions(self._relative_instructions + other_ris)
 
     def __str__(self):
+        return self.to_spec()
+
+    def __repr__(self):
         return "ReadInstruction(%s)" % self._relative_instructions
 
     def to_absolute(self, name2len):
