@@ -37,9 +37,9 @@ type_ = type  # keep python's type function
 
 class TypedSequence:
     """
-    This data container generalizes the typing when instantiating pyarrow arrays, tabels or batches.
+    This data container generalizes the typing when instantiating pyarrow arrays, tables or batches.
 
-    More specifically it add several features:
+    More specifically it adds several features:
     - Support extension types like ``datasets.features.Array2DExtensionType``:
         By default pyarrow arrays don't return extension arrays. One has to call
         ``pa.ExtensionArray.from_storage(type, pa.array(data, type.storage_type_name))``
@@ -75,11 +75,12 @@ class TypedSequence:
 
     """
 
-    def __init__(self, data, type=None, try_type=None):
+    def __init__(self, data, type=None, try_type=None, optimized_int_type=None):
         assert type is None or try_type is None, "You cannot specify both type and try_type"
         self.data = data
         self.type = type
         self.try_type = try_type  # is ignored if it doesn't match the data
+        self.optimized_int_type = optimized_int_type
 
     def __arrow_array__(self, type=None):
         """This function is called when calling pa.array(typed_sequence)"""
@@ -99,6 +100,14 @@ class TypedSequence:
                 raise TypeError(
                     "Specified try_type alters data. Please check that the type/feature that you provided match the type/features of the data."
                 )
+            if self.optimized_int_type and self.type is None and self.try_type is None:
+                if pa.types.is_int64(out.type):
+                    out = out.cast(self.optimized_int_type)
+                elif pa.types.is_list(out.type):
+                    if pa.types.is_int64(out.type.value_type):
+                        out = out.cast(pa.list_(self.optimized_int_type))
+                    elif pa.types.is_list(out.type.value_type) and pa.types.is_int64(out.type.value_type.value_type):
+                        out = out.cast(pa.list_(pa.list_(self.optimized_int_type)))
             return out
         except (TypeError, pa.lib.ArrowInvalid) as e:  # handle type errors and overflows
             if trying_type:
@@ -123,7 +132,20 @@ class TypedSequence:
                 raise
 
 
-class ArrowWriter(object):
+class OptimizedTypedSequence(TypedSequence):
+    def __init__(self, data, type=None, try_type=None, col=None, optimized_int_type=None):
+        optimized_int_type_by_col = {
+            "attention_mask": pa.int8(),  # binary tensor
+            "special_tokens_mask": pa.int8(),
+            "input_ids": pa.int32(),  # typical vocab size: 0-50k (max ~500k, never > 1M)
+            "token_type_ids": pa.int8(),  # binary mask; some (XLNetModel) use an additional token represented by a 2
+        }
+        if type is None and try_type is None:
+            optimized_int_type = optimized_int_type_by_col.get(col, None)
+        super().__init__(data, type=type, try_type=try_type, optimized_int_type=optimized_int_type)
+
+
+class ArrowWriter:
     """Shuffles and writes Examples to Arrow files."""
 
     def __init__(
@@ -157,8 +179,10 @@ class ArrowWriter(object):
         self._path = path
         if stream is None:
             self.stream = pa.OSFile(self._path, "wb")
+            self._closable_stream = True
         else:
             self.stream = stream
+            self._closable_stream = False
 
         self.fingerprint = fingerprint
         self.disable_nullable = disable_nullable
@@ -169,12 +193,29 @@ class ArrowWriter(object):
 
         self._num_examples = 0
         self._num_bytes = 0
-        self.current_rows: List[Dict[str, Any]] = []
+        self.current_examples: List[Dict[str, Any]] = []
+        self.current_rows: List[pa.Table] = []
         self.pa_writer: Optional[pa.RecordBatchStreamWriter] = None
 
     def __len__(self):
-        """ Return the number of writed and staged examples """
-        return self._num_examples + len(self.current_rows)
+        """Return the number of writed and staged examples"""
+        return self._num_examples + len(self.current_examples) + len(self.current_rows)
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.close()
+
+    def close(self):
+        # Try closing if opened; if closed: pyarrow.lib.ArrowInvalid: Invalid operation on closed file
+        if self.pa_writer:  # it might be None
+            try:
+                self.pa_writer.close()
+            except Exception:  # pyarrow.lib.ArrowInvalid, OSError
+                pass
+        if self._closable_stream and not self.stream.closed:
+            self.stream.close()  # This also closes self.pa_writer if it is opened
 
     def _build_writer(self, inferred_schema: pa.Schema):
         inferred_features = Features.from_arrow_schema(inferred_schema)
@@ -203,7 +244,8 @@ class ArrowWriter(object):
     def schema(self):
         return self._schema if self._schema is not None else []
 
-    def _build_metadata(self, info: DatasetInfo, fingerprint: Optional[str] = None) -> Dict[str, str]:
+    @staticmethod
+    def _build_metadata(info: DatasetInfo, fingerprint: Optional[str] = None) -> Dict[str, str]:
         info_keys = ["features"]  # we can add support for more DatasetInfo keys in the future
         info_as_dict = asdict(info)
         metadata = {}
@@ -212,11 +254,11 @@ class ArrowWriter(object):
             metadata["fingerprint"] = fingerprint
         return {"huggingface": json.dumps(metadata)}
 
-    def write_on_file(self):
-        """Write stored examples"""
-        if not self.current_rows:
+    def write_examples_on_file(self):
+        """Write stored examples from the write-pool of examples. It makes a table out of the examples and write it."""
+        if not self.current_examples:
             return
-        cols = sorted(self.current_rows[0].keys())
+        cols = sorted(self.current_examples[0].keys())
         schema = None if self.pa_writer is None and self.update_features else self._schema
         try_schema = self._schema if self.pa_writer is None and self.update_features else None
         arrays = []
@@ -224,12 +266,12 @@ class ArrowWriter(object):
         for col in cols:
             col_type = schema.field(col).type if schema is not None else None
             col_try_type = try_schema.field(col).type if try_schema is not None and col in try_schema.names else None
-            typed_sequence = TypedSequence(
-                [row[col] for row in self.current_rows], type=col_type, try_type=col_try_type
+            typed_sequence = OptimizedTypedSequence(
+                [row[col] for row in self.current_examples], type=col_type, try_type=col_try_type, col=col
             )
             pa_array = pa.array(typed_sequence)
             inferred_type = pa_array.type
-            first_example = pa.array(TypedSequence(typed_sequence.data[:1], type=inferred_type))[0]
+            first_example = pa.array(OptimizedTypedSequence(typed_sequence.data[:1], type=inferred_type))[0]
             if pa_array[0] != first_example:  # Sanity check (check for overflow in StructArray or ListArray)
                 raise OverflowError(
                     "There was an overflow in the {}. Try to reduce writer_batch_size to have batches smaller than 2GB".format(
@@ -241,19 +283,39 @@ class ArrowWriter(object):
         schema = pa.schema(zip(cols, inferred_types)) if self.pa_writer is None else self._schema
         table = pa.Table.from_arrays(arrays, schema=schema)
         self.write_table(table)
+        self.current_examples = []
+
+    def write_rows_on_file(self):
+        """Write stored rows from the write-pool of rows. It concatenates the single-row tables and it writes the resulting table."""
+        if not self.current_rows:
+            return
+        table = pa.concat_tables(self.current_rows).combine_chunks()
+        self.write_table(table)
         self.current_rows = []
 
     def write(self, example: Dict[str, Any], writer_batch_size: Optional[int] = None):
-        """Add a given Example to the write-pool which is written to file.
+        """Add a given Example to the write-pool of examples which is written to file.
 
         Args:
             example: the Example to add.
         """
-        self.current_rows.append(example)
+        self.current_examples.append(example)
+        if writer_batch_size is None:
+            writer_batch_size = self.writer_batch_size
+        if writer_batch_size is not None and len(self.current_examples) >= writer_batch_size:
+            self.write_examples_on_file()
+
+    def write_row(self, row: pa.Table, writer_batch_size: Optional[int] = None):
+        """Add a given single-row Table to the write-pool of rows which is written to file.
+
+        Args:
+            row: the row to add.
+        """
+        self.current_rows.append(row)
         if writer_batch_size is None:
             writer_batch_size = self.writer_batch_size
         if writer_batch_size is not None and len(self.current_rows) >= writer_batch_size:
-            self.write_on_file()
+            self.write_rows_on_file()
 
     def write_batch(
         self,
@@ -271,22 +333,24 @@ class ArrowWriter(object):
         for col in sorted(batch_examples.keys()):
             col_type = schema.field(col).type if schema is not None else None
             col_try_type = try_schema.field(col).type if try_schema is not None and col in try_schema.names else None
-            typed_sequence = TypedSequence(batch_examples[col], type=col_type, try_type=col_try_type)
+            typed_sequence = OptimizedTypedSequence(batch_examples[col], type=col_type, try_type=col_try_type, col=col)
             typed_sequence_examples[col] = typed_sequence
         pa_table = pa.Table.from_pydict(typed_sequence_examples)
         self.write_table(pa_table, writer_batch_size)
 
     def write_table(self, pa_table: pa.Table, writer_batch_size: Optional[int] = None):
-        """Write a batch of Example to file.
+        """Write a Table to file.
 
         Args:
-            example: the Example to add.
+            example: the Table to add.
         """
         if writer_batch_size is None:
             writer_batch_size = self.writer_batch_size
         if self.pa_writer is None:
             self._build_writer(inferred_schema=pa_table.schema)
-        pa_table = pa_table.cast(self._schema)
+        # reorder the arrays if necessary + cast to self._schema
+        # we can't simply use .cast here because we may need to change the order of the columns
+        pa_table = pa.Table.from_arrays([pa_table[name] for name in self._schema.names], schema=self._schema)
         batches: List[pa.RecordBatch] = pa_table.to_batches(max_chunksize=writer_batch_size)
         self._num_bytes += sum(batch.nbytes for batch in batches)
         self._num_examples += pa_table.num_rows
@@ -294,7 +358,8 @@ class ArrowWriter(object):
             self.pa_writer.write_batch(batch)
 
     def finalize(self, close_stream=True):
-        self.write_on_file()
+        self.write_rows_on_file()
+        self.write_examples_on_file()
         if self.pa_writer is None:
             if self._schema is not None:
                 self._build_writer(self._schema)
@@ -313,7 +378,7 @@ class ArrowWriter(object):
         return self._num_examples, self._num_bytes
 
 
-class BeamWriter(object):
+class BeamWriter:
     """
     Shuffles and writes Examples to Arrow files.
     The Arrow files are converted from Parquet files that are the output of Apache Beam pipelines.
@@ -416,14 +481,14 @@ class BeamWriter(object):
 def parquet_to_arrow(sources, destination):
     """Convert parquet files to arrow file. Inputs can be str paths or file-like objects"""
     stream = None if isinstance(destination, str) else destination
-    writer = ArrowWriter(path=destination, stream=stream)
     not_verbose = bool(logger.getEffectiveLevel() > WARNING)
-    for source in tqdm(sources, unit="sources", disable=not_verbose):
-        pf = pa.parquet.ParquetFile(source)
-        for i in tqdm(range(pf.num_row_groups), unit="row_groups", leave=False, disable=not_verbose):
-            df = pf.read_row_group(i).to_pandas()
-            for col in df.columns:
-                df[col] = df[col].apply(json.loads)
-            reconstructed_table = pa.Table.from_pandas(df)
-            writer.write_table(reconstructed_table)
+    with ArrowWriter(path=destination, stream=stream) as writer:
+        for source in tqdm(sources, unit="sources", disable=not_verbose):
+            pf = pa.parquet.ParquetFile(source)
+            for i in tqdm(range(pf.num_row_groups), unit="row_groups", leave=False, disable=not_verbose):
+                df = pf.read_row_group(i).to_pandas()
+                for col in df.columns:
+                    df[col] = df[col].apply(json.loads)
+                reconstructed_table = pa.Table.from_pandas(df)
+                writer.write_table(reconstructed_table)
     return destination
