@@ -32,18 +32,11 @@ from datasets.utils.mock_download_manager import MockDownloadManager
 
 from . import config, utils
 from .arrow_dataset import Dataset
-from .arrow_reader import HF_GCP_BASE_URL, ArrowReader, DatasetNotOnHfGcs, MissingFilesOnHfGcs
+from .arrow_reader import HF_GCP_BASE_URL, ArrowReader, DatasetNotOnHfGcs, MissingFilesOnHfGcs, ReadInstruction
 from .arrow_writer import ArrowWriter, BeamWriter
 from .dataset_dict import DatasetDict
 from .fingerprint import Hasher
-from .info import (
-    DATASET_INFO_FILENAME,
-    DATASET_INFOS_DICT_FILE_NAME,
-    LICENSE_FILENAME,
-    DatasetInfo,
-    DatasetInfosDict,
-    PostProcessedInfo,
-)
+from .info import DatasetInfo, DatasetInfosDict, PostProcessedInfo
 from .naming import camelcase_to_snakecase, filename_prefix_for_split
 from .splits import Split, SplitDict, SplitGenerator
 from .utils.download_manager import DownloadManager, GenerateMode
@@ -55,12 +48,6 @@ from .utils.logging import WARNING, get_logger
 
 logger = get_logger(__name__)
 
-FORCE_REDOWNLOAD = GenerateMode.FORCE_REDOWNLOAD
-REUSE_CACHE_IF_EXISTS = GenerateMode.REUSE_CACHE_IF_EXISTS
-REUSE_DATASET_IF_EXISTS = GenerateMode.REUSE_DATASET_IF_EXISTS
-
-MAX_DIRECTORY_NAME_LENGTH = 255
-
 
 class InvalidConfigName(ValueError):
     pass
@@ -68,10 +55,17 @@ class InvalidConfigName(ValueError):
 
 @dataclass
 class BuilderConfig:
-    """Base class for `DatasetBuilder` data configuration.
+    """Base class for :class:`DatasetBuilder` data configuration.
 
     DatasetBuilder subclasses with data configuration options should subclass
-    `BuilderConfig` and add their own properties.
+    :class:`BuilderConfig` and add their own properties.
+
+    Attributes:
+        name (:obj:`str`, default ``"default"``):
+        version (:class:`Version` or :obj:`str`, optional):
+        data_dir (:obj:`str`, optional):
+        data_files (:obj:`str` or :obj:`dict` or :obj:`list` or :obj:`tuple`, optional):
+        description (:obj:`str`, optional):
     """
 
     name: str = "default"
@@ -168,7 +162,7 @@ class BuilderConfig:
 
         if suffix:
             config_id = self.name + "-" + suffix
-            if len(config_id) > MAX_DIRECTORY_NAME_LENGTH:
+            if len(config_id) > config.MAX_DATASET_CONFIG_ID_READABLE_LENGTH:
                 config_id = self.name + "-" + Hasher.hash(suffix)
             return config_id
         else:
@@ -180,16 +174,16 @@ class DatasetBuilder:
 
     `DatasetBuilder` has 3 key methods:
 
-        * `datasets.DatasetBuilder.info`: documents the dataset, including feature
-            names, types, and shapes, version, splits, citation, etc.
-        * `datasets.DatasetBuilder.download_and_prepare`: downloads the source data
-            and writes it to disk.
-        * `datasets.DatasetBuilder.as_dataset`: generates a `Dataset`.
+        - :meth:`datasets.DatasetBuilder.info`: Documents the dataset, including feature
+          names, types, and shapes, version, splits, citation, etc.
+        - :meth:`datasets.DatasetBuilder.download_and_prepare`: Downloads the source data
+          and writes it to disk.
+        - :meth:`datasets.DatasetBuilder.as_dataset`: Generates a `Dataset`.
 
     **Configuration**: Some `DatasetBuilder`s expose multiple variants of the
     dataset by defining a `datasets.BuilderConfig` subclass and accepting a
     config object (or name) on construction. Configurable datasets expose a
-    pre-defined set of configurations in `datasets.DatasetBuilder.builder_configs`.
+    pre-defined set of configurations in :meth:`datasets.DatasetBuilder.builder_configs`.
     """
 
     # Default version.
@@ -290,7 +284,7 @@ class DatasetBuilder:
     @classmethod
     def get_all_exported_dataset_infos(cls) -> dict:
         """Empty dict if doesn't exist"""
-        dset_infos_file_path = os.path.join(cls.get_imported_module_dir(), DATASET_INFOS_DICT_FILE_NAME)
+        dset_infos_file_path = os.path.join(cls.get_imported_module_dir(), config.DATASETDICT_INFOS_FILENAME)
         if os.path.exists(dset_infos_file_path):
             return DatasetInfosDict.from_directory(cls.get_imported_module_dir())
         return {}
@@ -489,7 +483,7 @@ class DatasetBuilder:
             if download_config is None:
                 download_config = DownloadConfig(
                     cache_dir=os.path.join(self._cache_dir_root, "downloads"),
-                    force_download=bool(download_mode == FORCE_REDOWNLOAD),
+                    force_download=bool(download_mode == GenerateMode.FORCE_REDOWNLOAD),
                     use_etag=False,
                     use_auth_token=use_auth_token,
                 )  # We don't use etag for data files to speed up the process
@@ -508,11 +502,13 @@ class DatasetBuilder:
         lock_path = os.path.join(self._cache_dir_root, self._cache_dir.replace(os.sep, "_") + ".lock")
         with FileLock(lock_path):
             data_exists = os.path.exists(self._cache_dir)
-            if data_exists and download_mode == REUSE_DATASET_IF_EXISTS:
+            if data_exists and download_mode == GenerateMode.REUSE_DATASET_IF_EXISTS:
                 logger.warning("Reusing dataset %s (%s)", self.name, self._cache_dir)
+                # We need to update the info in case some splits were added in the meantime
+                # for example when calling load_dataset from multiple workers.
+                self.info = self._load_info()
                 self.download_post_processing_resources(dl_manager)
                 return
-
             logger.info("Generating dataset %s (%s)", self.name, self._cache_dir)
             if not is_remote_url(self._cache_dir_root):  # if cache dir is local, check for available space
                 if not utils.has_sufficient_disk_space(self.info.size_in_bytes or 0, directory=self._cache_dir_root):
@@ -685,6 +681,9 @@ class DatasetBuilder:
                         )
                         shutil.move(downloaded_resource_path, resource_path)
 
+    def _load_info(self) -> DatasetInfo:
+        return DatasetInfo.from_directory(self._cache_dir)
+
     def _save_info(self):
         lock_path = os.path.join(self._cache_dir_root, self._cache_dir.replace(os.sep, "_") + ".lock")
         with FileLock(lock_path):
@@ -750,7 +749,11 @@ class DatasetBuilder:
         return datasets
 
     def _build_single_dataset(
-        self, split: Union[str, Split], run_post_process: bool, ignore_verifications: bool, in_memory: bool = False
+        self,
+        split: Union[str, ReadInstruction, Split],
+        run_post_process: bool,
+        ignore_verifications: bool,
+        in_memory: bool = False,
     ):
         """as_dataset for a single split."""
         verify_infos = not ignore_verifications
@@ -813,7 +816,7 @@ class DatasetBuilder:
 
         return ds
 
-    def _as_dataset(self, split: Split = Split.TRAIN, in_memory: bool = False) -> Dataset:
+    def _as_dataset(self, split: Union[ReadInstruction, Split] = Split.TRAIN, in_memory: bool = False) -> Dataset:
         """Constructs a `Dataset`.
 
         This is the internal implementation to overwrite called when user calls
@@ -968,20 +971,19 @@ class GeneratorBasedBuilder(DatasetBuilder):
 
         fname = "{}-{}.arrow".format(self.name, split_generator.name)
         fpath = os.path.join(self._cache_dir, fname)
-        writer = ArrowWriter(features=self.info.features, path=fpath, writer_batch_size=self._writer_batch_size)
 
         generator = self._generate_examples(**split_generator.gen_kwargs)
         not_verbose = bool(logger.getEffectiveLevel() > WARNING)
-        try:
-            for key, record in utils.tqdm(
-                generator, unit=" examples", total=split_info.num_examples, leave=False, disable=not_verbose
-            ):
-                example = self.info.features.encode_example(record)
-                writer.write(example)
-        finally:
-            num_examples, num_bytes = writer.finalize()
+        with ArrowWriter(features=self.info.features, path=fpath, writer_batch_size=self._writer_batch_size) as writer:
+            try:
+                for key, record in utils.tqdm(
+                    generator, unit=" examples", total=split_info.num_examples, leave=False, disable=not_verbose
+                ):
+                    example = self.info.features.encode_example(record)
+                    writer.write(example)
+            finally:
+                num_examples, num_bytes = writer.finalize()
 
-        assert num_examples == num_examples, f"Expected to write {split_info.num_examples} but wrote {num_examples}"
         split_generator.split_info.num_examples = num_examples
         split_generator.split_info.num_bytes = num_bytes
 
@@ -1026,17 +1028,17 @@ class ArrowBasedBuilder(DatasetBuilder):
         fname = "{}-{}.arrow".format(self.name, split_generator.name)
         fpath = os.path.join(self._cache_dir, fname)
 
-        writer = ArrowWriter(path=fpath)
-
         generator = self._generate_tables(**split_generator.gen_kwargs)
         not_verbose = bool(logger.getEffectiveLevel() > WARNING)
-        for key, table in utils.tqdm(generator, unit=" tables", leave=False, disable=not_verbose):
-            writer.write_table(table)
-        num_examples, num_bytes = writer.finalize()
+        with ArrowWriter(features=self.info.features, path=fpath) as writer:
+            for key, table in utils.tqdm(generator, unit=" tables", leave=False, disable=not_verbose):
+                writer.write_table(table)
+            num_examples, num_bytes = writer.finalize()
 
         split_generator.split_info.num_examples = num_examples
         split_generator.split_info.num_bytes = num_bytes
-        self.info.features = writer._features
+        if self.info.features is None:
+            self.info.features = writer._features
 
 
 class MissingBeamOptions(ValueError):
@@ -1159,9 +1161,9 @@ class BeamBasedBuilder(DatasetBuilder):
             import apache_beam as beam
 
             fs = beam.io.filesystems.FileSystems
-            with fs.create(os.path.join(self._cache_dir, DATASET_INFO_FILENAME)) as f:
+            with fs.create(os.path.join(self._cache_dir, config.DATASET_INFO_FILENAME)) as f:
                 self.info._dump_info(f)
-            with fs.create(os.path.join(self._cache_dir, LICENSE_FILENAME)) as f:
+            with fs.create(os.path.join(self._cache_dir, config.LICENSE_FILENAME)) as f:
                 self.info._dump_license(f)
 
     def _prepare_split(self, split_generator, pipeline):
