@@ -5,10 +5,10 @@ from shutil import copyfile
 from typing import List
 
 from datasets import config
-from datasets.builder import FORCE_REDOWNLOAD, REUSE_CACHE_IF_EXISTS, DatasetBuilder, DownloadConfig
+from datasets.builder import DatasetBuilder
 from datasets.commands import BaseTransformersCLICommand
-from datasets.info import DATASET_INFOS_DICT_FILE_NAME
 from datasets.load import import_main_class, prepare_module
+from datasets.utils.download_manager import DownloadConfig, GenerateMode
 
 
 def run_beam_command_factory(args):
@@ -113,7 +113,9 @@ class RunBeamCommand(BaseTransformersCLICommand):
 
         for builder in builders:
             builder.download_and_prepare(
-                download_mode=REUSE_CACHE_IF_EXISTS if not self._force_redownload else FORCE_REDOWNLOAD,
+                download_mode=GenerateMode.REUSE_CACHE_IF_EXISTS
+                if not self._force_redownload
+                else GenerateMode.FORCE_REDOWNLOAD,
                 download_config=DownloadConfig(cache_dir=os.path.join(config.HF_DATASETS_CACHE, "downloads")),
                 save_infos=self._save_infos,
                 ignore_verifications=self._ignore_verifications,
@@ -126,7 +128,7 @@ class RunBeamCommand(BaseTransformersCLICommand):
         # Let's move it to the original directory of the dataset script, to allow the user to
         # upload them on S3 at the same time afterwards.
         if self._save_infos:
-            dataset_infos_path = os.path.join(builder_cls.get_imported_module_dir(), DATASET_INFOS_DICT_FILE_NAME)
+            dataset_infos_path = os.path.join(builder_cls.get_imported_module_dir(), config.DATASETDICT_INFOS_FILENAME)
 
             name = Path(path).name + ".py"
 
@@ -140,6 +142,6 @@ class RunBeamCommand(BaseTransformersCLICommand):
                 exit(1)
 
             # Move datasetinfo back to the user
-            user_dataset_infos_path = os.path.join(dataset_dir, DATASET_INFOS_DICT_FILE_NAME)
+            user_dataset_infos_path = os.path.join(dataset_dir, config.DATASETDICT_INFOS_FILENAME)
             copyfile(dataset_infos_path, user_dataset_infos_path)
             print("Dataset Infos file saved at {}".format(user_dataset_infos_path))
