@@ -4,10 +4,11 @@ from pathlib import Path
 from shutil import copyfile, rmtree
 from typing import Generator
 
-from datasets.builder import FORCE_REDOWNLOAD, REUSE_CACHE_IF_EXISTS, DatasetBuilder
+import datasets.config
+from datasets.builder import DatasetBuilder
 from datasets.commands import BaseTransformersCLICommand
-from datasets.info import DATASET_INFOS_DICT_FILE_NAME
 from datasets.load import import_main_class, prepare_module
+from datasets.utils.download_manager import GenerateMode
 from datasets.utils.filelock import logger as fl_logger
 from datasets.utils.logging import ERROR, get_logger
 
@@ -136,7 +137,9 @@ class TestCommand(BaseTransformersCLICommand):
         for j, builder in enumerate(get_builders()):
             print(f"Testing builder '{builder.config.name}' ({j + 1}/{n_builders})")
             builder.download_and_prepare(
-                download_mode=REUSE_CACHE_IF_EXISTS if not self._force_redownload else FORCE_REDOWNLOAD,
+                download_mode=GenerateMode.REUSE_CACHE_IF_EXISTS
+                if not self._force_redownload
+                else GenerateMode.FORCE_REDOWNLOAD,
                 ignore_verifications=self._ignore_verifications,
                 try_from_hf_gcs=False,
             )
@@ -148,7 +151,9 @@ class TestCommand(BaseTransformersCLICommand):
             # Let's move it to the original directory of the dataset script, to allow the user to
             # upload them on S3 at the same time afterwards.
             if self._save_infos:
-                dataset_infos_path = os.path.join(builder_cls.get_imported_module_dir(), DATASET_INFOS_DICT_FILE_NAME)
+                dataset_infos_path = os.path.join(
+                    builder_cls.get_imported_module_dir(), datasets.config.DATASETDICT_INFOS_FILENAME
+                )
                 name = Path(path).name + ".py"
                 combined_path = os.path.join(path, name)
                 if os.path.isfile(path):
@@ -161,7 +166,7 @@ class TestCommand(BaseTransformersCLICommand):
 
                 # Move dataset_info back to the user
                 if dataset_dir is not None:
-                    user_dataset_infos_path = os.path.join(dataset_dir, DATASET_INFOS_DICT_FILE_NAME)
+                    user_dataset_infos_path = os.path.join(dataset_dir, datasets.config.DATASETDICT_INFOS_FILENAME)
                     copyfile(dataset_infos_path, user_dataset_infos_path)
                     print("Dataset Infos file saved at {}".format(user_dataset_infos_path))
 
