@@ -31,8 +31,8 @@ def list_datasets(with_community_datasets=True, with_details=False):
     """List all the datasets scripts available on HuggingFace AWS bucket.
 
     Args:
-        with_community_datasets (Optional ``bool``): Include the community provided datasets (default: ``True``)
-        with_details (Optional ``bool``): Return the full details on the datasets instead of only the short name (default: ``False``)
+        with_community_datasets (``bool``, optional, default ``True``): Include the community provided datasets.
+        with_details (``bool``, optional, default ``False``): Return the full details on the datasets instead of only the short name.
     """
     api = HfApi()
     return api.dataset_list(with_community_datasets=with_community_datasets, id_only=bool(not with_details))
