@@ -62,7 +62,7 @@ class FileFreeLock(BaseFileLock):
         self._lock_file_fd = None
 
 
-class MetricInfoMixin(object):
+class MetricInfoMixin:
     """This base class exposes some attributes of MetricInfo
     at the base level of the Metric for easy access.
     """
@@ -72,7 +72,7 @@ class MetricInfoMixin(object):
 
     @property
     def info(self):
-        """ :class:`datasets.MetricInfo` object containing all the metadata in the metric."""
+        """:class:`datasets.MetricInfo` object containing all the metadata in the metric."""
         return self._metric_info
 
     @property
@@ -125,7 +125,7 @@ class MetricInfoMixin(object):
 
 
 class Metric(MetricInfoMixin):
-    """A Metrics is the base class and common API for all metrics.
+    """A Metric is the base class and common API for all metrics.
 
     Args:
         config_name (``str``): This is used to define a hash specific to a metrics computation script and prevents the metric's data
@@ -233,7 +233,7 @@ class Metric(MetricInfoMixin):
         return builder_data_dir
 
     def _create_cache_file(self, timeout=1) -> Tuple[str, FileLock]:
-        """ Create a new cache file. If the default cache file is used, we generated a new hash. """
+        """Create a new cache file. If the default cache file is used, we generated a new hash."""
         file_path = os.path.join(self.data_dir, f"{self.experiment_id}-{self.num_process}-{self.process_id}.arrow")
         filelock = None
         for i in range(self.max_concurrent_cache_files):
@@ -368,24 +368,23 @@ class Metric(MetricInfoMixin):
             self.file_paths = file_paths
             self.filelocks = filelocks
 
-    def compute(self, *args, **kwargs) -> Optional[dict]:
+    def compute(self, *, predictions=None, references=None, **kwargs) -> Optional[dict]:
         """Compute the metrics.
 
+        Usage of positional arguments is not allowed to prevent mistakes.
+
         Args:
-            We disallow the usage of positional arguments to prevent mistakes
-            `predictions` (Optional list/array/tensor): predictions
-            `references` (Optional list/array/tensor): references
-            `**kwargs` (Optional other kwargs): will be forwared to the metrics :func:`_compute` method (see details in the docstring)
+            predictions (list/array/tensor, optional): Predictions.
+            references (list/array/tensor, optional): References.
+            **kwargs (optional): Keyword arguments that will be forwarded to the metrics :meth:`_compute`
+                method (see details in the docstring).
 
         Return:
-            Dictionnary with the metrics if this metric is run on the main process (process_id == 0)
-            None if the metric is not run on the main process (process_id != 0)
-        """
-        if args:
-            raise ValueError("Please call `compute` using keyword arguments.")
+            dict or None
 
-        predictions = kwargs.pop("predictions", None)
-        references = kwargs.pop("references", None)
+            - Dictionary with the metrics if this metric is run on the main process (``process_id == 0``).
+            - None if the metric is not run on the main process (``process_id != 0``).
+        """
 
         if predictions is not None:
             self.add_batch(predictions=predictions, references=references)
@@ -422,8 +421,11 @@ class Metric(MetricInfoMixin):
             return None
 
     def add_batch(self, *, predictions=None, references=None):
-        """
-        Add a batch of predictions and references for the metric's stack.
+        """Add a batch of predictions and references for the metric's stack.
+
+        Args:
+            predictions (list/array/tensor, optional): Predictions.
+            references (list/array/tensor, optional): References.
         """
         batch = {"predictions": predictions, "references": references}
         batch = self.info.features.encode_batch(batch)
@@ -440,7 +442,12 @@ class Metric(MetricInfoMixin):
             )
 
     def add(self, *, prediction=None, reference=None):
-        """Add one prediction and reference for the metric's stack."""
+        """Add one prediction and reference for the metric's stack.
+
+        Args:
+            prediction (list/array/tensor, optional): Predictions.
+            reference (list/array/tensor, optional): References.
+        """
         example = {"predictions": prediction, "references": reference}
         example = self.info.features.encode_example(example)
         if self.writer is None:
@@ -513,8 +520,8 @@ class Metric(MetricInfoMixin):
         """Downloads and prepares dataset for reading.
 
         Args:
-            download_config (Optional ``datasets.DownloadConfig``: specific download configuration parameters.
-            dl_manager (Optional ``datasets.DownloadManager``): specific Download Manger to use
+            download_config (:class:`DownloadConfig`, optional): Specific download configuration parameters.
+            dl_manager (:class:`DownloadManager`, optional): Specific download manager to use.
         """
         if dl_manager is None:
             if download_config is None:
@@ -535,13 +542,12 @@ class Metric(MetricInfoMixin):
         `download_and_prepare`. It should download all required resources for the metric.
 
         Args:
-            dl_manager: (DownloadManager) `DownloadManager` used to download and cache
-                data..
+            dl_manager (:class:`DownloadManager`): `DownloadManager` used to download and cache data.
         """
         return None
 
     def _compute(self, *, predictions=None, references=None, **kwargs) -> Dict[str, Any]:
-        """ This method defines the common API for all the metrics in the library """
+        """This method defines the common API for all the metrics in the library"""
         raise NotImplementedError
 
     def __del__(self):
