@@ -16,7 +16,6 @@
 # Lint as: python3
 """Splits related API."""
 
-from __future__ import absolute_import, division, print_function
 
 import abc
 import collections
@@ -305,46 +304,39 @@ class _SubSplit(SplitBase):
 class NamedSplit(SplitBase):
     """Descriptor corresponding to a named split (train, test, ...).
 
-    Each descriptor can be composed with other using addition or slice. Ex:
+    Examples:
+        Each descriptor can be composed with other using addition or slice. Ex::
 
-    ```
-    split = datasets.Split.TRAIN.subsplit(datasets.percent[0:25]) + datasets.Split.TEST
-    ```
+            split = datasets.Split.TRAIN.subsplit(datasets.percent[0:25]) + datasets.Split.TEST
 
-    The resulting split will correspond to 25% of the train split merged with
-    100% of the test split.
+        The resulting split will correspond to 25% of the train split merged with
+        100% of the test split.
 
     Warning:
-        A split cannot be added twice, so the following will fail:
+        A split cannot be added twice, so the following will fail::
 
-    ```
-    split = (
-            datasets.Split.TRAIN.subsplit(datasets.percent[:25]) +
-            datasets.Split.TRAIN.subsplit(datasets.percent[75:])
-    )  # Error
-    split = datasets.Split.TEST + datasets.Split.ALL  # Error
-    ```
+            split = (
+                    datasets.Split.TRAIN.subsplit(datasets.percent[:25]) +
+                    datasets.Split.TRAIN.subsplit(datasets.percent[75:])
+            )  # Error
+            split = datasets.Split.TEST + datasets.Split.ALL  # Error
 
     Warning:
-        The slices can be applied only one time. So the following are valid:
+        The slices can be applied only one time. So the following are valid::
 
-    ```
-    split = (
-            datasets.Split.TRAIN.subsplit(datasets.percent[:25]) +
-            datasets.Split.TEST.subsplit(datasets.percent[:50])
-    )
-    split = (datasets.Split.TRAIN + datasets.Split.TEST).subsplit(datasets.percent[:50])
-    ```
+            split = (
+                    datasets.Split.TRAIN.subsplit(datasets.percent[:25]) +
+                    datasets.Split.TEST.subsplit(datasets.percent[:50])
+            )
+            split = (datasets.Split.TRAIN + datasets.Split.TEST).subsplit(datasets.percent[:50])
 
-        But not:
 
-    ```
-    train = datasets.Split.TRAIN
-    test = datasets.Split.TEST
-    split = train.subsplit(datasets.percent[:25]).subsplit(datasets.percent[:25])
-    split = (train.subsplit(datasets.percent[:25]) + test).subsplit(datasets.percent[:50])
-    ```
+        But not::
 
+            train = datasets.Split.TRAIN
+            test = datasets.Split.TEST
+            split = train.subsplit(datasets.percent[:25]).subsplit(datasets.percent[:25])
+            split = (train.subsplit(datasets.percent[:25]) + test).subsplit(datasets.percent[:50])
     """
 
     def __init__(self, name):
@@ -352,13 +344,13 @@ class NamedSplit(SplitBase):
         split_names_from_instruction = [split_instruction.split("[")[0] for split_instruction in name.split("+")]
         for split_name in split_names_from_instruction:
             if not re.match(_split_re, split_name):
-                raise ValueError(f"Split name should match '{_split_re}'' but got '{split_name}'.")
+                raise ValueError(f"Split name should match '{_split_re}' but got '{split_name}'.")
 
     def __str__(self):
         return self._name
 
     def __repr__(self):
-        return "NamedSplit('{name}')".format(name=self._name)
+        return f"NamedSplit({self._name!r})"
 
     def __eq__(self, other):
         """Equality: datasets.Split.TRAIN == 'train'."""
@@ -385,7 +377,7 @@ class NamedSplitAll(NamedSplit):
         super(NamedSplitAll, self).__init__("all")
 
     def __repr__(self):
-        return f"NamedSplitAll({self._name}"
+        return f"NamedSplitAll({self._name!r})"
 
     def get_read_instruction(self, split_dict):
         # Merge all dataset split together
@@ -393,25 +385,23 @@ class NamedSplitAll(NamedSplit):
         return sum(read_instructions, SplitReadInstruction())
 
 
-class Split(object):
+class Split:
     # pylint: disable=line-too-long
     """`Enum` for dataset splits.
 
     Datasets are typically split into different subsets to be used at various
     stages of training and evaluation.
 
-    * `TRAIN`: the training data.
-    * `VALIDATION`: the validation data. If present, this is typically used as
-        evaluation data while iterating on a model (e.g. changing hyperparameters,
-        model architecture, etc.).
-    * `TEST`: the testing data. This is the data to report metrics on. Typically
-        you do not want to use this during model iteration as you may overfit to it.
+    - `TRAIN`: the training data.
+    - `VALIDATION`: the validation data. If present, this is typically used as
+      evaluation data while iterating on a model (e.g. changing hyperparameters,
+      model architecture, etc.).
+    - `TEST`: the testing data. This is the data to report metrics on. Typically
+      you do not want to use this during model iteration as you may overfit to it.
 
     Note: All splits, including compositions inherit from `datasets.SplitBase`
 
-    See the
-    [guide on splits](https://github.com/huggingface/datasets/blob/master/docs/source/splits.rst)
-    for more information.
+    See the :doc:`guide on splits </splits>` for more information.
     """
     # pylint: enable=line-too-long
     TRAIN = NamedSplit("train")
@@ -433,7 +423,7 @@ SlicedSplitInfo = collections.namedtuple(
 )  # noqa: E231
 
 
-class SplitReadInstruction(object):
+class SplitReadInstruction:
     """Object containing the reading instruction for the dataset.
 
     Similarly to `SplitDescriptor` nodes, this object can be composed with itself,
@@ -559,14 +549,14 @@ class SplitGenerator:
     """Defines the split information for the generator.
 
     This should be used as returned value of
-    `GeneratorBasedBuilder._split_generators`.
-    See `GeneratorBasedBuilder._split_generators` for more info and example
+    :meth:`GeneratorBasedBuilder._split_generators`.
+    See :meth:`GeneratorBasedBuilder._split_generators` for more info and example
     of usage.
 
     Args:
-        name: `str`, name of the Split for which the generator will
+        name (str): Name of the Split for which the generator will
             create the examples.
-        gen_kwargs: `dict`, kwargs to forward to the _generate_examples() method
+        **gen_kwargs: Keyword arguments to forward to the :meth:`DatasetBuilder._generate_examples` method
             of the builder.
     """
 
